bluemath\_tk.datamining package
===============================

Submodules
----------

bluemath\_tk.datamining.kma module
----------------------------------

.. automodule:: bluemath_tk.datamining.kma
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.datamining.lhs module
----------------------------------

.. automodule:: bluemath_tk.datamining.lhs
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.datamining.mda module
----------------------------------

.. automodule:: bluemath_tk.datamining.mda
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.datamining.pca module
----------------------------------

.. automodule:: bluemath_tk.datamining.pca
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.datamining.som module
----------------------------------

.. automodule:: bluemath_tk.datamining.som
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: bluemath_tk.datamining
   :members:
   :undoc-members:
   :show-inheritance:
